@@ -16,3 +16,9 @@ main = do print $( lift (Foo "str1" 'c') )
 #endif
                           1.0## 1.0# 1# 1##) )
           print $( lift (In { out = Nothing }) )
+#if MIN_VERSION_template_haskell(2,7,0)
+          print $( lift (FamPrefix1 "str1" 'c') )
+          print $( lift (FamPrefix2 "str2") )
+          print $( lift (FamRec {famField = 'a'}) )
+          print $( lift ('a' :%%: 'b') )
+#endif
